@@ -1,3 +1,5 @@
+#![doc = include_str!("../README.md")]
+
 use std::{
     fmt::{self, Write as _},
     io::{self, stdout, Write as _},
@@ -203,6 +205,18 @@ function braille(a::Float64, b::Float64)
 end
 */
 
+/// Determines the dimensions of stdout.
+#[cfg(feature = "auto-width")]
+fn stdout_dimensions() -> (usize, usize) {
+    term_size::dimensions_stdout().unwrap_or((80, 30))
+}
+
+/// Determines the dimensions of stdout.
+#[cfg(not(feature = "auto-width"))]
+fn stdout_dimensions() -> (usize, usize) {
+    (80, 30)
+}
+
 impl ProgressBarTheme for DefaultProgressBarTheme {
     fn render(&self, pb: &ProgressBar) -> Result<(), RenderError> {
         let mut o = stdout();
@@ -254,8 +268,7 @@ impl ProgressBarTheme for DefaultProgressBarTheme {
         let max_width = pb
             .cfg
             .width
-            .or_else(|| term_size::dimensions_stdout().map(|x| x.0 as u32))
-            .unwrap_or(80);
+            .unwrap_or_else(|| stdout_dimensions().0 as u32);
 
         let bar_width = max_width
             .saturating_sub(left.len() as u32)
@@ -303,7 +316,7 @@ fn human_iter_unit(x: usize) -> (&'static str, f32) {
     } else if x > 10usize.pow(3) {
         ("K", 1e3)
     } else {
-        ("", 1e1)
+        ("", 1e0)
     }
 }
 
@@ -364,14 +377,12 @@ impl Unit {
 /// # Example
 ///
 /// ```rust
-/// # fn main() {
 /// use zzz::prelude::*;
 ///
 /// let mut bar = ProgressBar::with_target(123);
 /// for _ in 0..123 {
 ///     bar.add(1);
 /// }
-/// # }
 /// ```
 pub struct ProgressBar {
     /// Configuration to use.
@@ -532,7 +543,7 @@ impl ProgressBar {
         *self.message.get_mut().unwrap() = text.map(Into::into);
     }
 
-    /// Synchronized version fo `set_message`.
+    /// Synchronized version for `set_message`.
     pub fn set_message_sync(&self, text: Option<impl Into<String>>) {
         let mut message_lock = self.message.write().unwrap();
         *message_lock = text.map(Into::into);
@@ -556,7 +567,7 @@ impl ProgressBar {
         let left = 1. / self.progress()?;
         let elapsed = self.elapsed();
         let estimated_total = elapsed.mul_f32(left);
-        Some(estimated_total - elapsed)
+        Some(estimated_total.saturating_sub(elapsed))
     }
 
     /// Calculate the mean iterations per second since creation of the progress bar.
@@ -582,7 +593,7 @@ impl ProgressBar {
         (elapsed_sec % timer_sec) / timer_sec
     }
 
-    /// Forces a redraw of the progress-bar.
+    /// Forces a redraw of the progress bar.
     pub fn redraw(&self) {
         self.cfg.theme.render(self).unwrap();
         self.update_next_print();
